@@ -102,7 +102,9 @@
 
 (defconst mew-us-ascii "us-ascii")
 (defconst mew-utf-8 "utf-8")
+(defconst mew-iso-2022-jp-2 "iso-2022-jp-2")
 (defconst mew-cs-unknown 'unknown)
+(defconst mew-cs-m17n-list `(,mew-utf-8 ,mew-iso-2022-jp-2))
 
 (defconst mew-type-txt `(,mew-ct-txt ("charset" ,mew-us-ascii)))
 (defconst mew-type-msg `(,mew-ct-msg))
@@ -233,8 +235,8 @@
 (defsubst mew-regex-jmp-msg (msg)
   (concat  "^[ ]*" msg "[^0-9]"))
 
-(defconst mew-regex-case "^\\([-a-zA-Z0-9_][-a-zA-Z0-9_]+\\):\\(.*\\)")
-(defconst mew-regex-case2 "\\([-a-zA-Z0-9_][-a-zA-Z0-9_]+\\):")
+(defconst mew-regex-case "^\\([^-+$%*,:][^,:]+\\):\\(.*\\)")
+(defconst mew-regex-case2 "\\([^-+$%*,:][^,:]+\\):")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -281,7 +283,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2000-2002 Mew developing team.
+;; Copyright (C) 2000-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
