@@ -211,47 +211,44 @@ a text object to be saved can be specified."
 	  (cache (or cbuf (mew-buffer-message)))
 	  (syntax (mew-syntax-get-entry (mew-cache-decode-syntax cache) nums))
 	  (action "Save")
-	  (buf (generate-new-buffer mew-buffer-prefix))
 	  PLUS1P limit have-hdrp bodyp beg end cdpl file ct ctl
 	  doit append-p)
-     (save-excursion
-       ;; Due to mew-decode-broken, the filename may be changed.
-       ;; So, save it here.
-       (and syntax (setq cdpl (mew-syntax-get-cdp syntax)))
-       (setq ctl (mew-syntax-get-ct syntax))
-       (setq file (mew-syntax-get-filename cdpl ctl))
-       ;; First of all, we should determine which part the user want to
-       ;; save due to the ambiguity.
-       ;; "y" on Message/Rfc822
-       ;;     - msg/txt      the entire msg or its body?
-       ;;     - msg/mul/txt  the entire msg or its part 1?
-       ;; We have to make use of mew-decode-syntax
-       ;; in the cache buffer due to the PGP/MIME dilemma.
-       ;; We need the correct LIMIT.
-       (if (mew-syntax-message-p syntax)
-	   (let ((bodyname "the body") body bct plus1p)
-	     (setq body (mew-syntax-get-part syntax))
-	     (when (mew-syntax-multipart-p body)
-	       (setq plus1p t)
-	       (setq bodyname "the part 1 text")
-	       (setq body (mew-syntax-get-entry body '(1))))
-	     (setq bct (mew-syntax-get-value (mew-syntax-get-ct body) 'cap))
-	     (if (mew-ct-textp bct)
-		 (if (y-or-n-p (format "Save the entire message (y) or %s (n) " bodyname))
-		     (setq have-hdrp t)
-		   (if plus1p
-		       (setq nums (nreverse (cons 1 (nreverse nums))))
-		     (setq bodyp t))
-		   (setq PLUS1P (mew-syntax-get-privacy body)))
-	       (setq have-hdrp t))))
-       ;; Now, let's analyze the message in the burst buffer.
-       ;; This is lengthy, though, avoidable.
-       (setq limit (length nums))
-       (if (or PLUS1P bodyp) ;; VERY important for PGP/MIME
-	   (setq limit (1+ limit)))
-       ;;
-       (set-buffer buf)
-       (mew-erase-buffer)
+     ;; Due to mew-decode-broken, the filename may be changed.
+     ;; So, save it here.
+     (and syntax (setq cdpl (mew-syntax-get-cdp syntax)))
+     (setq ctl (mew-syntax-get-ct syntax))
+     (setq file (mew-syntax-get-filename cdpl ctl))
+     ;; First of all, we should determine which part the user want to
+     ;; save due to the ambiguity.
+     ;; "y" on Message/Rfc822
+     ;;     - msg/txt      the entire msg or its body?
+     ;;     - msg/mul/txt  the entire msg or its part 1?
+     ;; We have to make use of mew-decode-syntax
+     ;; in the cache buffer due to the PGP/MIME dilemma.
+     ;; We need the correct LIMIT.
+     (if (mew-syntax-message-p syntax)
+	 (let ((bodyname "the body") body bct plus1p)
+	   (setq body (mew-syntax-get-part syntax))
+	   (when (mew-syntax-multipart-p body)
+	     (setq plus1p t)
+	     (setq bodyname "the part 1 text")
+	     (setq body (mew-syntax-get-entry body '(1))))
+	   (setq bct (mew-syntax-get-value (mew-syntax-get-ct body) 'cap))
+	   (if (mew-ct-textp bct)
+	       (if (y-or-n-p (format "Save the entire message (y) or %s (n) " bodyname))
+		   (setq have-hdrp t)
+		 (if plus1p
+		     (setq nums (nreverse (cons 1 (nreverse nums))))
+		   (setq bodyp t))
+		 (setq PLUS1P (mew-syntax-get-privacy body)))
+	     (setq have-hdrp t))))
+     ;; Now, let's analyze the message in the burst buffer.
+     ;; This is lengthy, though, avoidable.
+     (setq limit (length nums))
+     (if (or PLUS1P bodyp) ;; VERY important for PGP/MIME
+	 (setq limit (1+ limit)))
+     ;;
+     (with-temp-buffer
        (mew-insert-message fld msg mew-cs-text-for-read nil)
        (mew-dinfo-set limit 'no-cs-conv t alt)
        (mew-decode-for-edit)
@@ -279,15 +276,20 @@ a text object to be saved can be specified."
        ;;
        (if (not doit)
 	   (message "Did not save anything")
-	 (let (linebasep fromcs tocs charset)
+	 (let (linebasep fromcs tocs charset writecs)
 	   (save-restriction
 	     (narrow-to-region beg end)
 	     (goto-char (point-min))
 	     (setq ct (mew-syntax-get-value ctl 'cap))
 	     ;; Allow Message/Rfc822. It's user's risk.
 	     (setq linebasep (or (mew-ct-textp ct) (mew-ct-linebasep ct)))
-	     (if (and askcs linebasep mew-mule-p)
-		 (setq tocs (read-coding-system "Coding-system: ")))
+	     (if linebasep
+		 (setq writecs mew-cs-text-for-write)
+	       (setq writecs mew-cs-binary))
+	     (when (and askcs linebasep mew-mule-p)
+	       (setq tocs (read-coding-system "Coding-system: "))
+	       (if (mew-cs-raw-p tocs)
+		   (setq writecs tocs tocs nil)))
 	     (when have-hdrp
 	       (goto-char (point-min))
 	       (mew-header-delete-lines mew-field-delete-common)
@@ -306,11 +308,9 @@ a text object to be saved can be specified."
 		(point-min) (point-max) (or fromcs mew-cs-autoconv))
 	       (mew-cs-encode-region (point-min) (point-max) tocs))
 	     (mew-frwlet
-	      mew-cs-dummy
-	      (if linebasep mew-cs-text-for-write mew-cs-binary)
+	      mew-cs-dummy writecs
 	      ;; do not specify 'no-msg
-	      (write-region (point-min) (point-max) file append-p))))))
-     (mew-remove-buffer buf))))
+	      (write-region (point-min) (point-max) file append-p)))))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -420,15 +420,11 @@ If executed with '\\[universal-argument]', coding-system is asked."
 ;;;
 
 (defun mew-summary-burst-body (fld msg folder &optional num)
-  (save-excursion
-    (let ((buf (generate-new-buffer mew-buffer-prefix))
-	  ret errmsg mstr m)
-      (set-buffer buf)
-      (mew-erase-buffer)
+  (let (ret errmsg mstr m)
+    (with-temp-buffer
       (mew-insert-message fld msg mew-cs-text-for-read nil)
       (mew-dinfo-set 1 nil nil nil) ;; xxx
       (mew-decode-for-edit)
-      (mew-local-folder-check folder)
       (cond
        ((not (mew-syntax-multipart-p (mew-syntax-get-part mew-decode-syntax)))
 	(message "Cannot burst"))
@@ -441,12 +437,11 @@ If executed with '\\[universal-argument]', coding-system is asked."
 	    (message "Nothing was processed")
 	  (mew-touch-folder folder)
 	  (setq ret (list mstr (int-to-string (1- m)))))))
-      (mew-remove-buffer buf)
       (if errmsg (error errmsg))
       ret)))
 
 (defun mew-summary-burst-part (part folder newmsg &optional num)
-  (let (n len nums entry)
+  (let (n len nums entry file)
     (setq n 1)
     (cond
      (num
@@ -462,6 +457,7 @@ If executed with '\\[universal-argument]', coding-system is asked."
 	(setq newmsg (mew-summary-burst-part entry folder newmsg)))
        ((string= (mew-syntax-get-value (mew-syntax-get-ct entry) 'cap)
 		 mew-ct-msg)
+	(setq file (mew-expand-folder folder (int-to-string newmsg)))
 	(mew-frwlet
 	 mew-cs-dummy mew-cs-text-for-write
 	 (write-region
@@ -469,8 +465,8 @@ If executed with '\\[universal-argument]', coding-system is asked."
 	  ;; This is RFC 822 message.
 	  ;; So, body is a single text/plain.
 	  (mew-syntax-get-end (mew-syntax-get-part entry))
-	  (mew-expand-folder folder (int-to-string newmsg))
-	  nil 'no-msg))
+	  file nil 'no-msg))
+	(mew-set-file-modes file)
 	(setq newmsg (1+ newmsg))))
       (setq n (1+ n))
       (setq nums (list n)))
@@ -483,7 +479,7 @@ If executed with '\\[universal-argument]', coding-system is asked."
      (if (and mew-use-burst-folder-history mew-burst-last-folder)
 	 (setq default mew-burst-last-folder)
        (setq default (mew-inbox-folder))) ;; local folder
-     (setq mew-burst-last-folder (mew-input-folder default 'local-only))
+     (setq mew-burst-last-folder (mew-input-local-folder default))
      mew-burst-last-folder))
 
 (defun mew-summary-burst (&optional arg)
@@ -496,14 +492,15 @@ If called with '\\[universal-argument]', the current part is de-capsulated."
 	 (folder (mew-input-burst-folder))
 	 (num (if arg (mew-syntax-number)))
 	 ret)
-     (message "Bursting...")
-     (setq ret (mew-summary-burst-body fld msg folder num))
-     (when ret
-       (message "Bursting...done")
-       (if (y-or-n-p (format "Go to %s? " folder))
-	   (mew-summary-visit-folder folder 'goend))
-       (message "Messages from %s to %s were extracted in %s"
-		(nth 0 ret) (nth 1 ret) folder)))))
+     (when (and folder (mew-local-folder-check folder 'ask))
+       (message "Bursting...")
+       (setq ret (mew-summary-burst-body fld msg folder num))
+       (when ret
+	 (message "Bursting...done")
+	 (if (y-or-n-p (format "Go to %s? " folder))
+	     (mew-summary-visit-folder folder 'goend))
+	 (message "Messages from %s to %s were extracted in %s"
+		  (nth 0 ret) (nth 1 ret) folder))))))
 
 (defun mew-summary-burst-multi ()
   "De-capsulate messages embedded in the messages marked with '@'."
@@ -511,13 +508,15 @@ If called with '\\[universal-argument]', the current part is de-capsulated."
   (mew-summary-multi-msgs
    (let ((folder (mew-input-burst-folder))
 	 (targets FLD-MSG-LIST))
-     (message "Bursting...")
-     (while targets
-       (mew-summary-burst-body (car (car targets)) (cdr (car targets)) folder)
-       (setq targets (cdr targets)))
-     (message "Bursting...done")
-     (if (y-or-n-p (format "Go to %s? " folder))
-	 (mew-summary-visit-folder folder 'goend)))))
+     (when (and folder (mew-local-folder-check folder 'ask))
+       (message "Bursting...")
+       (while targets
+	 (mew-summary-burst-body
+	  (car (car targets)) (cdr (car targets)) folder)
+	 (setq targets (cdr targets)))
+       (message "Bursting...done")
+       (if (y-or-n-p (format "Go to %s? " folder))
+	   (mew-summary-visit-folder folder 'goend))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -532,11 +531,8 @@ If called with '\\[universal-argument]', the current part is de-capsulated."
 	 (sep1 (make-string 70 ?-))
 	 (sep2 (make-string 30 ?-))
 	 (folder (mew-input-burst-folder))
-	 (buf (get-buffer-create mew-buffer-prefix))
 	 start mstr m done)
-     (save-excursion
-       (set-buffer buf)
-       (mew-erase-buffer)
+     (with-temp-buffer
        (mew-insert-message fld msg mew-cs-text-for-read nil)
        (mew-set-buffer-multibyte t)
        (if (not (re-search-forward sep1 nil t))
@@ -566,7 +562,6 @@ If called with '\\[universal-argument]', the current part is de-capsulated."
 	 (message "Bursting...done")
 	 (mew-touch-folder folder)
 	 (setq done t)))
-     (mew-remove-buffer buf)
      (if (and done (y-or-n-p (format "Go to %s? " folder)))
 	 (mew-summary-visit-folder folder 'goend)))))
 
@@ -760,13 +755,10 @@ mew-summary-reedit."
 	  (msg (mew-summary-message-number))
 	  (nfld mew-temp-dir)
 	  (nmsg (mew-folder-new-message nfld 'num-only))
-	  (buf (generate-new-buffer mew-buffer-prefix))
 	  nfile)
-     (save-excursion
+     (with-temp-buffer
        ;; First, let's remove garbage and make a valid message
        ;; into a file.
-       (set-buffer buf)
-       (mew-erase-buffer)
        (mew-insert-message fld msg mew-cs-text-for-read nil)
        (mew-set-buffer-multibyte t)
        (goto-char (point-min))
@@ -783,8 +775,7 @@ mew-summary-reedit."
 	 ;; A new message is stored in the temporary directory
 	 (mew-summary-reedit-for-message nfld nmsg nil nil nil)
 	 (run-hooks 'mew-draft-mode-edit-again-hook)
-	 (mew-delete-file nfile)))
-     (mew-remove-buffer buf))))
+	 (mew-delete-file nfile))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -972,7 +963,7 @@ mew-summary-reedit."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2002 Mew developing team.
+;; Copyright (C) 1999-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
