@@ -140,7 +140,7 @@
 		   (not (file-directory-p (mew-expand-folder folder))))
 	  (if (y-or-n-p (format "%s does not exist. Create it? " folder))
 	      (mew-local-folder-check folder)
-	    (error "Edit Fcc:")))
+	    (mew-encode-error "Edit Fcc:")))
 	(setq ret (cons folder ret))))
     (nreverse ret)))
 
@@ -228,9 +228,8 @@
 ;;; Message-Id:, Date:
 ;;;
 
-(defun mew-encode-id-date (pnm case resentp)
-  (let ((msgid (mew-smtp-message-id case))
-	(time (current-time)))
+(defun mew-encode-id-date (pnm msgid &optional resentp)
+  (let ((time (current-time)))
     (cond
      (resentp
       (mew-header-delete-lines (list mew-resent-date: mew-resent-message-id:))
@@ -378,16 +377,8 @@
       ;; Let's backup
       (if (mew-attach-p)
 	  (progn
-	    (mew-attach-clear)
-	    (cond
-	     ((mew-encode-syntax-have-multiple-parts)
-	      (setq multip t))
-	     ((mew-encode-syntax-have-one-part)
-	      ;; A user may want to do any MIME stuff to the body
-	      (setq mew-encode-syntax (mew-syntax-get-part mew-encode-syntax)))
-	     (t
-	      ;; xxx error but ...
-	      )))
+	    (setq multip t)
+	    (mew-attach-clear))
 	(setq mew-encode-syntax
 	      (mew-encode-syntax-single "text.txt" (list mew-ct-txt))))
       (mew-encode-make-backup))
@@ -403,7 +394,7 @@
     (mew-encode-from case resentp)
     (mew-encode-learn-aliases resentp)
     ;;
-    (setq msgid-logtime (mew-encode-id-date pnm case resentp))
+    (setq msgid-logtime (mew-encode-id-date pnm (mew-smtp-message-id case) resentp))
     (mew-smtp-set-msgid pnm (nth 0 msgid-logtime))
     (mew-smtp-set-logtime pnm (nth 1 msgid-logtime))
     ;;
@@ -415,6 +406,8 @@
     (unless headerp
       (mew-encode-set-privacy pnm privacy)
       (let ((mew-inherit-encode-signer (or signer (mew-get-my-address))))
+	(goto-char (mew-header-end)) ;; due to illegal null lines in the header
+	(forward-line)
 	(if multip
 	    (mew-encode-make-multi)
 	  (mew-encode-make-single))))
@@ -453,16 +446,8 @@
     (unless headerp
       (if (mew-attach-p)
 	  (progn
-	    (mew-attach-clear)
-	    (cond
-	     ((mew-encode-syntax-have-multiple-parts)
-	      (setq multip t))
-	     ((mew-encode-syntax-have-one-part)
-	      ;; A user may want to do any MIME stuff to the body
-	      (setq mew-encode-syntax (mew-syntax-get-part mew-encode-syntax)))
-	     (t
-	      ;; xxx error but ...
-	      )))
+	    (setq multip t)
+	    (mew-attach-clear))
 	(setq mew-encode-syntax
 	      (mew-encode-syntax-single "text.txt" (list mew-ct-txt))))
       (mew-encode-make-backup))
@@ -474,7 +459,7 @@
     ;;
     (mew-encode-from case nil)
     ;;
-    (setq msgid-logtime (mew-encode-id-date pnm case nil))
+    (setq msgid-logtime (mew-encode-id-date pnm (mew-nntp-message-id case)))
     (mew-nntp2-set-msgid pnm (nth 0 msgid-logtime))
     (mew-nntp2-set-logtime pnm (nth 1 msgid-logtime))
     ;;
@@ -486,6 +471,8 @@
     (unless headerp
       (mew-encode-set-privacy pnm privacy)
       (let ((mew-inherit-encode-signer (or signer (mew-get-my-address))))
+	(goto-char (mew-header-end)) ;; due to illegal null lines in the header
+	(forward-line)
 	(if multip
 	    (mew-encode-make-multi)
 	  (mew-encode-make-single))))
@@ -500,9 +487,8 @@
 ;;;
 
 (defun mew-encode-make-single ()
-  (goto-char (mew-header-end)) ;; due to illegal null lines in the header
-  (forward-line)
-  (mew-encode-singlepart mew-encode-syntax nil nil t))
+  ;; Just after the header
+  (mew-encode-singlepart mew-encode-syntax nil nil t 'cover))
 
 (defun mew-encode-charset-8bitp (charset)
   (let ((case-fold-search t))
@@ -637,7 +623,7 @@
       (mew-encode-error (concat mew-prog-mime-encode " does not exist"))))
     (list (if charset (list "charset" charset)) cte)))
 
-(defun mew-encode-singlepart (syntax &optional path depth buffered)
+(defun mew-encode-singlepart (syntax &optional path depth buffered coverp)
   ;; path is nil if called make-single or security multipart
   ;; buffered is t if called make-single
   (run-hook-with-args 'mew-encode-singlepart-hook
@@ -651,7 +637,7 @@
 	 (privacy (mew-syntax-get-privacy syntax))
 	 (mew-inherit-7bit (mew-encode-limit-7bitp privacy))
 	 (beg (point))
-	 charset-cte charset bodybeg)
+	 charset-cte charset bodybeg cst ask-cst)
     (setq charset-cte (mew-encode-mime-body ctl cte (or buffered file)))
     (goto-char beg)
     (setq charset (nth 0 charset-cte))
@@ -678,6 +664,20 @@
       (mew-encode-security-multipart
        beg privacy depth (mew-syntax-get-decrypters syntax)))
     (goto-char (point-max))
+    (when (and coverp (setq cst (nth 1 charset)))
+      (cond
+       ((null mew-ask-charset)
+	;; not ask
+	)
+       ((eq mew-ask-charset t)
+	(if (mew-member-case-equal cst mew-cs-m17n-list)
+	    (setq ask-cst t)))
+       ((listp mew-ask-charset)
+	(unless (mew-member-case-equal cst mew-ask-charset)
+	  (setq ask-cst t))))
+      (if (and ask-cst
+	       (not (y-or-n-p (format "%s is used. OK? " cst))))
+	  (mew-encode-error "Modify body")))
     (mew-case-equal cte mew-8bit)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -686,39 +686,46 @@
 ;;;
 
 (defun mew-encode-make-multi ()
-  ;; delete delimiter
-  (goto-char (mew-header-end)) ;; due to illegal null lines in the header
-  (forward-line)
-  (let ((beg (point))
-	(path (mew-expand-folder mew-attach-folder))
-	(multip t)
-	buffered)
-    ;; Just after the header
-    ;; See if a cover page is empty or not
-    (save-excursion
-      (while (and (looking-at "^$") (not (eobp)))
-	(forward-line))
-      (if (not (eobp))
+  ;; Just after the header
+  (let (beg path multip buffered privacy first ct)
+    (if (mew-encode-syntax-have-one-part)
+	;; A user may want to do any MIME stuff to the body
+	(progn
+	  (setq mew-encode-syntax (mew-syntax-get-part mew-encode-syntax))
+	  (setq buffered t))
+      ;; See if a cover page is empty or not
+      (setq beg (point))
+      (save-excursion
+	(while (and (looking-at "^$") (not (eobp)))
+	  (forward-line))
+	(unless (eobp)
 	  ;; The cover page exists.
-	  (setq buffered t)
+	  (setq buffered t)))
+      (setq path (mew-expand-folder mew-attach-folder))
+      (if buffered
+	  ;; The cover page exists.
+	  (setq multip t)
 	;; The cover page does not exist.
 	(delete-region beg (point-max))
 	;; Remove the cover page entry from the syntax.
 	(setq mew-encode-syntax
 	      (mew-syntax-remove-entry mew-encode-syntax '(1)))
-	(when (and (mew-encode-syntax-have-one-part)
-		   (mew-ct-textp 
-		    (mew-syntax-get-value
-		     (mew-syntax-get-ct
-		      (mew-syntax-get-part mew-encode-syntax)))))
-	  (setq path (expand-file-name
-		      (mew-syntax-get-file mew-encode-syntax) path))
-	  (setq mew-encode-syntax (mew-syntax-get-part mew-encode-syntax))
-	  (setq multip nil))))
+	;; After removing the over page, see if this message has
+	;; only one text part.
+	(if (not (mew-encode-syntax-have-one-part))
+	    (setq multip t)
+	  (setq first (mew-syntax-get-part mew-encode-syntax))
+	  (setq ct (mew-syntax-get-value (mew-syntax-get-ct first) 'cap))
+	  (if (not (mew-ct-textp ct))
+	      (setq multip t)		   
+	    (setq path (expand-file-name
+			(mew-syntax-get-file mew-encode-syntax) path))
+	    (setq privacy (mew-syntax-get-privacy mew-encode-syntax))
+	    (setq mew-encode-syntax (mew-syntax-get-part mew-encode-syntax))
+	    (mew-syntax-set-privacy mew-encode-syntax privacy)))))
     (if multip
 	(mew-encode-multipart mew-encode-syntax path 0 buffered)
-      (goto-char beg)
-      (mew-encode-singlepart mew-encode-syntax path nil nil))))
+      (mew-encode-singlepart mew-encode-syntax path nil nil 'cover))))
 
 (defvar mew-default-boundary "--%s(%s_%s)--")
 
@@ -744,7 +751,7 @@
 	 (beg (point))
 	 (cnt mew-syntax-magic)
 	 (8bit-cnt 0)
-	 8bitp cte-pos)
+	 8bitp cte-pos cover)
     (mew-header-insert mew-ct: (list ct (list "boundary" boundary)))
     (setq cte-pos (point))
     (and cd (mew-header-insert mew-cd: cd))
@@ -752,10 +759,18 @@
       (insert "\n--" boundary "\n")
       (if (mew-syntax-multipart-p (aref syntax cnt))
 	  (setq 8bitp (mew-encode-multipart 
-		       (aref syntax cnt) fullname (1+ depth)))
+		       (aref syntax cnt)
+		       fullname
+		       (1+ depth)))
+	(if (and (= depth 0) (= cnt mew-syntax-magic ))
+	    (setq cover t)
+	  (setq cover nil))
 	(setq 8bitp (mew-encode-singlepart
-		     (aref syntax cnt) fullname (1+ depth)
-		     (if (eq cnt mew-syntax-magic) buffered nil))))
+		     (aref syntax cnt)
+		     fullname
+		     (1+ depth)
+		     (if (eq cnt mew-syntax-magic) buffered nil)
+		     cover)))
       (if 8bitp (setq 8bit-cnt (1+ 8bit-cnt)))
       (setq cnt (1+ cnt)))
     (insert "\n--" boundary "--\n")
@@ -954,7 +969,7 @@
   ;; called on the beginning of a header
   (let ((case-fold-search t)
 	(buf (current-buffer))
-	tmpbuf hd-end mimep charset cte body-beg body-end)
+	hd-end mimep charset cte body-beg body-end)
     (unless (re-search-forward mew-eoh nil t)
       (goto-char (point-max)))
     (setq hd-end (point-marker))
@@ -973,14 +988,10 @@
       (forward-line)
       (setq body-beg (point))
       (setq body-end (point-max))
-      (setq tmpbuf (generate-new-buffer mew-buffer-prefix))
-      (save-excursion
-	(set-buffer tmpbuf)
-	(mew-erase-buffer)
+      (with-temp-buffer
 	(mew-insert-buffer-substring buf body-beg body-end)
 	(mew-cs-decode-region (point-min) (point-max) mew-cs-autoconv)
 	(setq charset (mew-charset-guess-region (point-min) (point-max))))
-      (mew-remove-buffer tmpbuf)
       (when (mew-encode-charset-8bitp charset)
 	(setq cte (mew-charset-to-cte charset))
 	(if (null cte) (setq cte mew-b64))
@@ -1149,7 +1160,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2002 Mew developing team.
+;; Copyright (C) 1996-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
