@@ -21,7 +21,7 @@
 ;;;
 
 (defvar mew-imap-info-list
-  '("server" "port" "process" "ssh-process" "status"
+  '("server" "port" "process" "ssh-process" "ssl-process" "status"
     "directive" "bnm"
     "rtrs" "dels" "refs" "rmvs" "kils" "uidl" "range"
     "rttl" "rcnt" "dttl" "dcnt" "jcnt" "rfl" "hlds"
@@ -73,8 +73,14 @@
 ;;; Filters
 ;;;
 
+(defun mew-imap-secure-p (pnm)
+  (or (mew-imap-get-ssh-process pnm) (mew-imap-get-ssl-process pnm)))
+ 
 (defun mew-imap-command-capability (pro pnm)
-  (mew-net-status (mew-imap-get-bnm pnm) "Auth'ing")
+  (mew-net-status (mew-imap-get-bnm pnm)
+		  "Auth'ing"
+		  nil
+		  (mew-imap-secure-p pnm))
   (mew-imap-process-send-string pro pnm "CAPABILITY"))
 
 (defun mew-imap-command-authentication (pro pnm)
@@ -129,10 +135,13 @@
       (mew-imap-set-status pnm "list")
       (mew-imap-command-list pro pnm))
      (t
-      (mew-imap-process-send-string pro pnm "SELECT %s" mailbox)))))
+      (mew-imap-process-send-string pro pnm "SELECT \"%s\"" mailbox)))))
 
 (defun mew-imap-command-uid (pro pnm)
-  (mew-net-status (mew-imap-get-bnm pnm) "Checking")
+  (mew-net-status (mew-imap-get-bnm pnm)
+		  "Checking"
+		  nil
+		  (mew-imap-secure-p pnm))
   (let ((directive (mew-imap-get-directive pnm))
 	(refs (mew-imap-get-refs pnm)) ;; (uid siz del (+fld msg))
 	(rmvs (mew-imap-get-rmvs pnm))
@@ -314,7 +323,7 @@
       (mew-imap-set-rtrs pnm (cdr rtrs))
       (setq dst (mew-bnm-to-mailbox dst))
       (mew-imap-set-rfl pnm rtr)
-      (mew-imap-process-send-string pro pnm "UID COPY %s %s" uid dst))))
+      (mew-imap-process-send-string pro pnm "UID COPY %s \"%s\"" uid dst))))
 
 (defun mew-imap-command-create (pro pnm)
   (let* ((rtrs (mew-imap-get-rtrs pnm))
@@ -322,7 +331,7 @@
 	 (dst (nth 0 rtr))) ;; 'exec only
     (mew-imap-set-rtrs pnm (cons rtr rtrs))
     (setq dst (mew-bnm-to-mailbox dst))
-    (mew-imap-process-send-string pro pnm "CREATE %s" dst)))
+    (mew-imap-process-send-string pro pnm "CREATE \"%s\"" dst)))
 
 (defun mew-imap-command-wmbx (pro pnm)
   ;; xxx
@@ -346,7 +355,8 @@
 
 (defun mew-imap-command-dels (pro pnm)
   (mew-net-status1
-   (mew-imap-get-bnm pnm) (mew-imap-get-dttl pnm) (mew-imap-get-dcnt pnm))
+   (mew-imap-get-bnm pnm) (mew-imap-get-dttl pnm) (mew-imap-get-dcnt pnm)
+   (mew-imap-secure-p pnm))
   (let ((dels (mew-imap-get-dels pnm))
 	num)
     (if (null dels)
@@ -381,7 +391,8 @@
 		   (mew-imap-get-rttl pnm)
 		   (mew-imap-get-rcnt pnm)
 		   (nth 1 (car (mew-imap-get-rtrs pnm)))
-		   'zero)
+		   'zero
+		   (mew-imap-secure-p pnm))
   (let* ((directive (mew-imap-get-directive pnm))
 	 (rtrs (mew-imap-get-rtrs pnm))
 	 (dels (mew-imap-get-dels pnm))
@@ -494,7 +505,10 @@
 
 (defun mew-imap-command-list (pro pnm)
   (mew-imap-message pnm "Collecting mailbox list...")
-  (mew-net-status (mew-imap-get-bnm pnm) "Listing")
+  (mew-net-status (mew-imap-get-bnm pnm)
+		  "Listing"
+		  nil
+		  (mew-imap-secure-p pnm))
   (mew-imap-process-send-string pro pnm "LIST \"\" *"))
 
 (defun mew-imap-command-post-list (pro pnm)
@@ -509,7 +523,7 @@
 	  (setq sep (mew-match-string 1))
 	  (unless (string= sep "NIL")
 	    (setq regex (concat "\\([^" sep "]+\\)$"))
-	    (setq mailboxes (cons (list mew-imap-inbox-folder sep) mailboxes))))
+	    (setq mailboxes (cons (mew-folder-func mew-imap-inbox-folder sep) mailboxes))))
 	(setq mbx (mew-match-string 2))
 	(let ((case-fold-search nil))
 	  (if (string-match "^INBOX" mbx)
@@ -518,20 +532,20 @@
 	(cond
 	 ((null regex)
 	  (unless (string= mailbox mew-imap-inbox-folder)
-	    (setq mailboxes (cons (list mailbox mbx) mailboxes))))
+	    (setq mailboxes (cons (mew-folder-func mailbox mbx) mailboxes))))
 	 ((string= mailbox mew-imap-inbox-folder)
 	  ())
 	 ((string-match friendp mailbox)
 	  (setq friends (cons mailbox friends))
-	  (setq mailboxes (cons (list mailbox nil) mailboxes)))
+	  (setq mailboxes (cons (mew-folder-func mailbox) mailboxes)))
 	 ((string-match regex mailbox)
 	  (setq subnm (match-string 1 mailbox))
-	  (setq mailboxes (cons (list mailbox subnm) mailboxes)))))
+	  (setq mailboxes (cons (mew-folder-func mailbox subnm) mailboxes)))))
       (forward-line))
     (unless case (setq case mew-case-default))
     (setq mailboxes (nreverse mailboxes))
-    (setq mailboxes (cons (list (mew-imap-queue-folder case) nil) mailboxes))
-    (setq mailboxes (cons (list (mew-imap-trash-folder case) nil) mailboxes))
+    (setq mailboxes (cons (mew-folder-func (mew-imap-queue-folder case)) mailboxes))
+    (setq mailboxes (cons (mew-folder-func (mew-imap-trash-folder case)) mailboxes))
     (mew-imap-folder-set case mailboxes friends)
     (mew-imap-set-status pnm "logout")
     (mew-imap-command-logout pro pnm)))
@@ -739,7 +753,7 @@
 	 (pnm (mew-imap-info-name case mailbox))
 	 (buf (get-buffer-create (mew-imap-buffer-name pnm)))
 	 (no-msg (eq directive 'biff))
-	 process sshpro sshname lport)
+	 process sshname sshpro sslname sslpro lport)
     (if (mew-imap-get-process pnm)
 	(message "Another IMAP process is running. Try later")
       (cond
@@ -751,7 +765,12 @@
 	  (when lport
 	    (setq process (mew-imap-open pnm "localhost" lport no-msg)))))
        (sslp
-	(setq process (mew-open-ssl-stream pnm nil server sslport)))
+ 	(setq sslpro (mew-open-ssl-stream server sslport))
+ 	(when sslpro
+ 	  (setq sslname (process-name sslpro))
+	  (setq lport (mew-ssl-pnm-to-lport sslname))
+ 	  (when lport
+ 	    (setq process (mew-imap-open pnm "localhost" lport no-msg)))))
        (t
 	(setq process (mew-imap-open pnm server port no-msg))))
       (if (null process)
@@ -760,7 +779,7 @@
 	    (mew-sinfo-set-refile
 	     (nconc (mew-sinfo-get-refile) (mew-sinfo-get-refile-back)))
 	    (mew-sinfo-set-refile-back nil))
-	(mew-summary-lock process "IMAPing")
+	(mew-summary-lock process "IMAPing" (or sshpro sslpro))
 	(mew-sinfo-set-scan-form (mew-summary-scan-form bnm))
 	(mew-sinfo-set-scan-id nil)
 	(mew-info-clean-up pnm)
@@ -768,6 +787,7 @@
 	(mew-imap-message pnm "Communicating with the IMAP server...")
 	(mew-imap-set-process pnm process)
 	(mew-imap-set-ssh-process pnm sshpro)
+	(mew-imap-set-ssl-process pnm sslpro)
 	(mew-imap-set-server pnm server)
 	(mew-imap-set-port pnm port)
 	(mew-imap-set-user pnm (mew-imap-user case))
@@ -838,7 +858,9 @@
        (mew-net-status2 (mew-imap-get-bnm pnm)
 			(mew-imap-get-rttl pnm)
 			(mew-imap-get-rcnt pnm)
-			(nth 1 (car (mew-imap-get-rtrs pnm)))))
+			(nth 1 (car (mew-imap-get-rtrs pnm)))
+			nil
+			(mew-imap-secure-p pnm)))
      (cond
       ((and (goto-char (point-max)) (forward-line -1) (looking-at  "\\*"))
        ;; untagged message
@@ -869,6 +891,7 @@
   (let* ((pnm (process-name process))
 	 (directive (mew-imap-get-directive pnm))
 	 (sshpro (mew-imap-get-ssh-process pnm))
+	 (sslpro (mew-imap-get-ssl-process pnm))
 	 (rttl (mew-imap-get-rttl pnm))
 	 (dttl (mew-imap-get-dttl pnm))
 	 (jcnt (mew-imap-get-jcnt pnm))
@@ -947,11 +970,14 @@
 	  (t
 	   (mew-imap-message pnm "%d message groups deleted" dttl))))))
      ;;
+     (mew-net-status-clear (mew-imap-get-bnm pnm))
      (mew-info-clean-up pnm)
      (set-buffer-modified-p nil)
      (mew-summary-unlock)
      (if (and (processp sshpro) (not mew-ssh-keep-connection))
 	 (process-send-string sshpro "exit\n"))
+     (if (and (processp sslpro) (not mew-ssl-keep-connection))
+ 	 (delete-process sslpro))
      (unless (eq directive 'biff)
        (run-hooks 'mew-imap-sentinel-non-biff-hook))
      (run-hooks 'mew-imap-sentinel-hook)
@@ -1010,9 +1036,9 @@
       (if alist
 	  alist
 	(list
-	 (list mew-imap-inbox-folder nil)
-	 (list (mew-imap-trash-folder case) nil)
-	 (list (mew-imap-queue-folder case) nil))))))
+	 (mew-folder-func mew-imap-inbox-folder)
+	 (mew-folder-func (mew-imap-trash-folder case))
+	 (mew-folder-func (mew-imap-queue-folder case)))))))
 
 (defun mew-imap-friend-folder-list (&optional case no-load)
   (unless case (setq case mew-case-default))
@@ -1058,7 +1084,7 @@
   (let ((bnm (mew-summary-folder-name 'ext))
 	(case (mew-sinfo-get-case)))
     (if mew-config-cases
-	(setq case (mew-input-case case "IMAP"))) ;; xxx mew-case-input
+	(setq case (mew-input-case case "IMAP")))
     (mew-imap-retrieve case 'list bnm)))
 
 (defun mew-imap-folder-insert (case folder)
@@ -1070,14 +1096,14 @@
 	 sub)
     (when (string-match regex folder)
       (setq sub (match-string 1 folder))
-      (setq mailboxes (cons (list folder sub) mailboxes))
+      (setq mailboxes (cons (mew-folder-func folder sub) mailboxes))
       (when (string-match friendp folder)
 	(setq friends (cons folder friends)))
       (mew-imap-folder-set case mailboxes friends)
       t)))
 
 (defun mew-imap-separator (case)
-  (or (nth 1 (assoc mew-imap-inbox-folder (mew-imap-folder-alist case)))
+  (or (cdr (assoc mew-imap-inbox-folder (mew-imap-folder-alist case)))
       mew-path-separator)) ;; xxx
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -1122,7 +1148,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2002 Mew developing team.
+;; Copyright (C) 2002-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
