@@ -86,6 +86,7 @@
   (define-key mew-summary-mode-map "Z"    'mew-status-update)
   (define-key mew-summary-mode-map "#"    'mew-summary-print)
   (define-key mew-summary-mode-map "|"    'mew-summary-pipe-message)
+  (define-key mew-summary-mode-map "\\"   'mew-summary-cmd-msg)
   (define-key mew-summary-mode-map "q"    'mew-summary-suspend)
   (define-key mew-summary-mode-map "Q"    'mew-summary-quit)
   (define-key mew-summary-mode-map "C"    'mew-summary-set-case)
@@ -106,11 +107,12 @@
   (define-key mew-summary-mode-map "\et"  'mew-summary-uudecode)
   (define-key mew-summary-mode-map "\es"  'mew-summary-unshar)
   (define-key mew-summary-mode-map "\eb"  'mew-summary-burst-multi)
+  (define-key mew-summary-mode-map "\e\\" 'mew-summary-cmd-msgs)
   (define-key mew-summary-mode-map "v"    'mew-summary-toggle-disp-msg)
   (define-key mew-summary-mode-map "\C-c\C-l" 'mew-summary-convert-local-cs)
   (define-key mew-summary-mode-map "\C-c\C-z" 'mew-summary-decode-pgp)
-  (define-key mew-summary-mode-map "\C-c\C-x" 'mew-summary-x-face)
   (define-key mew-summary-mode-map "\C-c\C-q" 'mew-summary-kill)
+  (define-key mew-summary-mode-map "\C-c\C-x" 'mew-summary-x-face)
   (define-key mew-summary-mode-map "\C-c\C-k" 'mew-summary-kill-subprocess)
   (define-key mew-summary-mode-map "^"    'mew-summary-thread-parent)
   (define-key mew-summary-mode-map "&"    'mew-summary-thread-child)
@@ -160,9 +162,11 @@
   (define-key mew-summary-mode-map "x"    'mew-summary-exec)
   (define-key mew-summary-mode-map "X"    'mew-summary-exec-one)
   (define-key mew-summary-mode-map "lx"   'mew-summary-exec-offline)
+  (define-key mew-summary-mode-map "lX"   'mew-summary-exec-offline-one)
   (define-key mew-summary-mode-map "mo"   'mew-summary-mark-refile)
   (define-key mew-summary-mode-map "mc"   'mew-summary-mark-copy)
   (define-key mew-summary-mode-map "md"   'mew-summary-mark-delete)
+  (define-key mew-summary-mode-map "m/"   'mew-summary-mark-virtual)
   (define-key mew-summary-mode-map "m\ed" 'mew-summary-mark-unlink)
   (define-key mew-summary-mode-map "mxd"  'mew-summary-exec-delete)
   (define-key mew-summary-mode-map "mx\ed" 'mew-summary-exec-unlink)
@@ -591,7 +595,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2000-2002 Mew developing team.
+;; Copyright (C) 2000-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
