@@ -20,7 +20,7 @@
 ;;;
 
 (defvar mew-nntp-info-list
-  '("server" "port" "process" "ssh-process" "status"
+  '("server" "port" "process" "ssh-process" "ssl-process" "status"
     "directive" "bnm"
     "rtrs" "refs" "range"
     "rttl" "rcnt" "hlds"
@@ -61,8 +61,14 @@
 ;;; Filters
 ;;;
 
+(defun mew-nntp-secure-p (pnm)
+  (or (mew-nntp-get-ssh-process pnm) (mew-nntp-get-ssl-process pnm)))
+
 (defun mew-nntp-command-mode-reader (pro pnm)
-  (mew-net-status (mew-nntp-get-bnm pnm) "Connecting")
+  (mew-net-status (mew-nntp-get-bnm pnm)
+		  "Connecting"
+		  nil
+		  (mew-nntp-secure-p pnm))
   (mew-nntp-process-send-string pro "MODE READER"))
 
 (defun mew-nntp-command-authinfo (pro pnm)
@@ -92,7 +98,10 @@
       (mew-nntp-process-send-string pro "GROUP %s" newsgroup)))))
 
 (defun mew-nntp-command-xover (pro pnm)
-  (mew-net-status (mew-nntp-get-bnm pnm) "Checking")
+  (mew-net-status (mew-nntp-get-bnm pnm)
+		  "Checking"
+		  nil
+		  (mew-nntp-secure-p pnm))
   (let (beg end)
     (if (re-search-forward "^[0-9]+ +[0-9]+ +\\([0-9]+\\) +\\([0-9]+\\) +[-.a-zA-Z0-9]+" nil t)
 	(progn
@@ -163,7 +172,8 @@
 		   (mew-nntp-get-rttl pnm)
 		   (mew-nntp-get-rcnt pnm)
 		   (nth 1 (car (mew-nntp-get-rtrs pnm)))
-		   'zero)
+		   'zero
+		   (mew-nntp-secure-p pnm))
   (let* ((directive (mew-nntp-get-directive pnm))
 	 (rtrs (mew-nntp-get-rtrs pnm))
 	 (rtr (car rtrs))
@@ -247,7 +257,10 @@
     (mew-nntp-command-article pro pnm)))
 
 (defun mew-nntp-command-list (pro pnm)
-  (mew-net-status (mew-nntp-get-bnm pnm) "Listing")
+  (mew-net-status (mew-nntp-get-bnm pnm)
+		  "Listing"
+		  nil
+		  (mew-nntp-secure-p pnm))
   (mew-nntp-message pnm "Collecting newsgroup list...")
   (mew-nntp-process-send-string pro "LIST"))
 
@@ -378,7 +391,7 @@
 	 (pnm (mew-nntp-info-name case newsgroup))
 	 (buf (get-buffer-create (mew-nntp-buffer-name pnm)))
 	 (no-msg (eq directive 'biff))
-	 process sshpro sshname lport)
+	 process sshname sshpro sslname sslpro lport)
     (if (mew-nntp-get-process pnm)
 	(message "Another NNTP process is running. Try later")
       (cond
@@ -390,11 +403,16 @@
 	  (when lport
 	    (setq process (mew-nntp-open pnm "localhost" lport no-msg)))))
        (sslp
-	(setq process (mew-open-ssl-stream pnm nil server sslport)))
+	(setq sslpro (mew-open-ssl-stream server sslport))
+	(when sslpro
+	  (setq sslname (process-name sslpro))
+	  (setq lport (mew-ssl-pnm-to-lport sslname))
+	  (when lport
+	    (setq process (mew-nntp-open pnm "localhost" lport no-msg)))))
        (t
 	(setq process (mew-nntp-open pnm server port no-msg))))
       (when process
-	(mew-summary-lock process "NNTPing")
+	(mew-summary-lock process "NNTPing" (or sshpro sslpro))
 	(mew-sinfo-set-scan-form (mew-summary-scan-form bnm))
 	(mew-sinfo-set-scan-id nil)
 	(mew-info-clean-up pnm)
@@ -402,6 +420,7 @@
 	(mew-nntp-message pnm "Communicating with the NNTP server...")
 	(mew-nntp-set-process pnm process)
 	(mew-nntp-set-ssh-process pnm sshpro)
+	(mew-nntp-set-ssl-process pnm sslpro)
 	(mew-nntp-set-server pnm server)
 	(mew-nntp-set-port pnm port)
 	(mew-nntp-set-user pnm (mew-nntp-user case))
@@ -455,7 +474,9 @@
        (mew-net-status2 (mew-nntp-get-bnm pnm)
 			(mew-nntp-get-rttl pnm)
 			(mew-nntp-get-rcnt pnm)
-			(nth 1 (car (mew-nntp-get-rtrs pnm)))))
+			(nth 1 (car (mew-nntp-get-rtrs pnm)))
+			nil
+			(mew-nntp-secure-p pnm)))
      (cond
       ((and (and (goto-char (1- (point-max))) (looking-at "\n$"))
 	    (and (goto-char (point-min)) (looking-at "^\\([45][0-9][0-9]\\)")))
@@ -488,6 +509,7 @@
   (let* ((pnm (process-name process))
 	 (directive (mew-nntp-get-directive pnm))
 	 (sshpro (mew-nntp-get-ssh-process pnm))
+	 (sslpro (mew-nntp-get-ssl-process pnm))
 	 (rttl (mew-nntp-get-rttl pnm))
 	 (bnm (mew-nntp-get-bnm pnm))
 	 (hlds (mew-nntp-get-hlds pnm))
@@ -527,11 +549,14 @@
 	   (mew-lisp-save file msgid)
 	   (mew-summary-folder-cache-save))))))
      ;;
+     (mew-net-status-clear (mew-nntp-get-bnm pnm))
      (mew-info-clean-up pnm)
      (set-buffer-modified-p nil)
      (mew-summary-unlock)
      (if (and (processp sshpro) (not mew-ssh-keep-connection))
 	 (process-send-string sshpro "exit\n"))
+     (if (and (processp sslpro) (not mew-ssl-keep-connection))
+	 (delete-process sslpro))
      (run-hooks 'mew-nntp-sentinel-hook))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -597,7 +622,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2002 Mew developing team.
+;; Copyright (C) 1999-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
