@@ -18,14 +18,14 @@
     "case" ;; save for re-edit, not for sending
     ;; parameters used internally
     "server" "port" "ssh-server" "user"
-    "status" "ssh-process" "messages"
+    "status" "ssh-process" "ssl-process" "messages"
     ;; parameters used internally and should be initialized
     "string" "error" "done"))
 
 (mew-info-defun "mew-nntp2-" mew-nntp2-info-list)
 
 (defvar mew-nntp2-info-list-save-length 6)
-(defvar mew-nntp2-info-list-clean-length 13)
+(defvar mew-nntp2-info-list-clean-length 14)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -197,7 +197,7 @@
 	 (sshsrv (mew-nntp-ssh-server case))
 	 (sslp (mew-nntp-ssl case))
 	 (sslport (mew-nntp-ssl-port case))
-	 process sshname sshpro lport errmsg)
+	 process sshname sshpro sslname sslpro lport errmsg)
     (cond
      ((null (mew-nntp2-get-newsgroups pnm))
       (message "No newsgroups!"))
@@ -209,19 +209,29 @@
       (cond
        (sshsrv
 	(setq sshpro (mew-open-ssh-stream server port sshsrv))
-	(mew-nntp2-set-ssh-process pnm sshpro)
 	(when sshpro
 	  (setq sshname (process-name sshpro))
 	  (setq lport (mew-ssh-pnm-to-lport sshname))
 	  (when lport
 	    (setq process (mew-nntp2-open pnm "localhost" lport)))))
        (sslp
-	(setq process (mew-open-ssl-stream pnm nil server sslport)))
+	(setq sslpro (mew-open-ssl-stream server sslport))
+	(when sslpro
+	  (setq sslname (process-name sslpro))
+	  (setq lport (mew-ssl-pnm-to-lport sslname))
+	  (when lport
+	    (setq process (mew-nntp2-open pnm "localhost" lport)))))
        (t
 	(setq process (mew-nntp2-open pnm server port))))
       (if (null process)
 	  (progn
-	    (setq errmsg (concat "Cannot connect to the NNTP server"))
+	    (cond
+	     ((and sshsrv (null sshpro))
+	      (setq errmsg "Cannot create to the SSH connection"))
+	     ((and sslp (null sslpro))
+	      (setq errmsg "Cannot create to the SSL connection"))
+	     (t
+	      (setq errmsg "Cannot connect to the NNTP server")))
 	    (mew-nntp2-set-error pnm errmsg)
 	    (mew-nntp2-queue case errmsg))
 	(mew-info-clean-up pnm mew-nntp2-info-list-clean-length)
@@ -229,6 +239,8 @@
 	(mew-nntp2-set-server pnm server)
 	(mew-nntp2-set-port pnm port)
 	(mew-nntp2-set-ssh-server pnm sshsrv)
+	(mew-nntp2-set-ssh-process pnm sshpro)
+	(mew-nntp2-set-ssl-process pnm sslpro)
 	(mew-nntp2-set-user pnm (mew-nntp-user case))
 	(mew-nntp2-set-status pnm "greeting")
 	(set-process-buffer process (current-buffer))
@@ -297,11 +309,14 @@
 (defun mew-nntp2-sentinel (process event)
   (let* ((pnm (process-name process))
 	 (done (mew-nntp2-get-done pnm))
-	 (sshpro (mew-nntp2-get-ssh-process pnm)))
+	 (sshpro (mew-nntp2-get-ssh-process pnm))
+	 (sslpro (mew-nntp2-get-ssl-process pnm)))
     (mew-nntp2-debug "NNTP SENTINEL" event)
     (mew-info-clean-up pnm)
     (if (and (processp sshpro) (not mew-ssh-keep-connection))
 	(process-send-string sshpro "exit\n"))
+    (if (and (processp sslpro) (not mew-ssl-keep-connection))
+	(delete-process sslpro))
     (if done (message "Posting in background...done"))
     (run-hooks 'mew-nntp2-sentinel-hook)))
 
@@ -322,7 +337,7 @@
     (setq file (nth 0 file-info) info (nth 1 file-info))
     (setq nname (mew-concat-folder qfld (file-name-nondirectory file)))
     (if (mew-draft-p)
-	(mew-smtp-set-case pnm (mew-tinfo-get-case)))
+	(mew-nntp2-set-case pnm (mew-tinfo-get-case)))
     ;;
     (let* ((n mew-nntp2-info-list-save-length)
 	   (data (make-vector n nil))
@@ -347,13 +362,14 @@
 	(msgid (mew-nntp2-get-msgid pnm))
 	(newsgroups (mew-nntp2-get-newsgroups pnm))
 	(server (mew-nntp2-get-server pnm))
-	(buf (generate-new-buffer mew-buffer-prefix)))
-    (save-excursion
-      (set-buffer buf)
-      (mew-erase-buffer)
+	(sshsrv (mew-nntp2-get-ssh-server pnm))
+	(sslp (mew-nntp2-get-ssl-process pnm)))
+    (with-temp-buffer
       (and logtime (insert logtime))
       (and msgid (insert " id=" msgid))
       (and server (insert " server=" server))
+      (and sshsrv (insert " sshsrv=" sshsrv))
+      (and sslp (insert " SSL"))
       (and newsgroups (insert " newsgroups=" newsgroups))
       (if err
 	  (insert " status=" "("
@@ -363,14 +379,13 @@
       (insert "\n")
       (write-region (point-min) (point-max)
 		    (expand-file-name mew-nntp-log-file mew-conf-path)
-		    'append 'no-msg))
-    (mew-remove-buffer buf)))
+		    'append 'no-msg))))
 
 (provide 'mew-nntp2)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2002 Mew developing team.
+;; Copyright (C) 1999-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
