@@ -8,7 +8,7 @@
 (require 'mew)
 
 (defvar mew-pop-msgid-file ".mew-msgid")
-(defvar mew-pop-folder-alist '(("$inbox")))
+(defvar mew-pop-folder-alist (list (mew-folder-func mew-pop-inbox-folder)))
 (defun mew-pop-folder-alist ()
   mew-pop-folder-alist)
 
@@ -18,7 +18,7 @@
 ;;;
 
 (defvar mew-pop-info-list
-  '("server" "port" "process" "ssh-process" "status"
+  '("server" "port" "process" "ssh-process" "ssl-process" "status"
     "directive" "bnm"
     "rtrs" "dels" "refs" "rmvs" "kils" "left" "uidl" "range"
     "rttl" "rcnt" "dttl" "dcnt" "hlds"
@@ -43,7 +43,7 @@
     ("user"          nil ("\\+OK" . "pass") ("-ERR" . "wpwd2"))
     ("pass"          nil ("\\+OK" . "list") ("-ERR" . "wpwd"))
     ("list"          t   ("\\+OK" . "uidl"))
-    ("uidl"          t   ("\\+OK" . "umsg") ("-ERR" . "pre-retr"))
+    ("uidl"          t   ("\\+OK" . "umsg") ("-ERR" . "nouidl"))
     ("dels"	     nil ("\\+OK" . "dels"))
     ("retr"          t   ("\\+OK" . "dele"))
     ("dele"          nil ("\\+OK" . "retr"))
@@ -63,8 +63,14 @@
 ;;; Filters
 ;;;
 
+(defun mew-pop-secure-p (pnm)
+  (or (mew-pop-get-ssh-process pnm) (mew-pop-get-ssl-process pnm)))
+
 (defun mew-pop-command-capa (pro pnm)
-  (mew-net-status (mew-pop-get-bnm pnm) "Auth'ing")
+  (mew-net-status (mew-pop-get-bnm pnm)
+		  "Auth'ing"
+		  nil
+		  (mew-pop-secure-p pnm))
   (if (re-search-forward "<[^<>]+@[^<>]+>" nil t)
       (mew-pop-set-key pnm (mew-match-string 0)))
   (mew-pop-process-send-string pro "CAPA"))
@@ -157,7 +163,10 @@
     (mew-pop-command-quit2 pro pnm)))
 
 (defun mew-pop-command-list (pro pnm)
-  (mew-net-status (mew-pop-get-bnm pnm) "Checking")
+  (mew-net-status (mew-pop-get-bnm pnm)
+		  "Checking"
+		  nil
+		  (mew-pop-secure-p pnm))
   (let ((directive (mew-pop-get-directive pnm)))
     (cond
      ((or (eq directive 'get) (eq directive 'exec) (eq directive 'sync))
@@ -181,6 +190,23 @@
       (mew-pop-set-status pnm "quit")
       (mew-pop-command-quit pro pnm))))
 
+;; The POP server does not support UIDL.
+(defun mew-pop-command-nouidl (pro pnm)
+  (let ((directive (mew-pop-get-directive pnm))
+	rtrs)
+    (if (or (eq directive 'scan) (eq directive 'exec) (eq directive 'sync))
+	(progn
+	  (mew-pop-message pnm "POP server does not support this command")
+	  (mew-pop-command-quit2 pro pnm)) ;; xxx not to set "done"
+      (mew-pop-set-size pnm 0) ;; To get the entire message
+      (mew-pop-set-rttl pnm (mew-pop-get-left pnm))
+      (when (mew-pop-get-delete pnm)
+	(setq rtrs (mew-pop-get-rtrs pnm)) ;; (num nil siz nil)
+	(while rtrs
+	  (setcar (nthcdr 3 (car rtrs)) t)
+	  (setq rtrs (cdr rtrs))))
+      (mew-pop-command-pre-retr pro pnm))))
+
 (defun mew-pop-command-umsg (pro pnm)
   (let* ((directive (mew-pop-get-directive pnm))
 	 (list-msgs (mew-pop-get-rtrs pnm))
@@ -295,7 +321,8 @@
 
 (defun mew-pop-command-dels (pro pnm)
   (mew-net-status1
-   (mew-pop-get-bnm pnm) (mew-pop-get-dttl pnm) (mew-pop-get-dcnt pnm))
+   (mew-pop-get-bnm pnm) (mew-pop-get-dttl pnm) (mew-pop-get-dcnt pnm)
+   (mew-pop-secure-p pnm))
   (let ((directive (mew-pop-get-directive pnm))
 	(dels (mew-pop-get-dels pnm))
 	(left (mew-pop-get-left pnm))
@@ -333,7 +360,8 @@
 		   (mew-pop-get-rttl pnm)
 		   (mew-pop-get-rcnt pnm)
 		   (nth 2 (car (mew-pop-get-rtrs pnm)))
-		   'zero)
+		   'zero
+		   (mew-pop-secure-p pnm))
   (let* ((directive (mew-pop-get-directive pnm))
 	 (rtrs (mew-pop-get-rtrs pnm))
 	 (rtr  (car rtrs))
@@ -583,7 +611,7 @@
 	 (pnm (mew-pop-info-name case))
 	 (buf (get-buffer-create (mew-pop-buffer-name pnm)))
 	 (no-msg (eq directive 'biff))
-	 process sshpro sshname lport)
+	 process sshname sshpro sslname sslpro lport)
     (if (mew-pop-get-process pnm)
 	(message "Another POP process is running. Try later")
       (cond
@@ -595,13 +623,18 @@
 	  (when lport
 	    (setq process (mew-pop-open pnm "localhost" lport no-msg)))))
        (sslp
-	(setq process (mew-open-ssl-stream pnm nil server sslport)))
+	(setq sslpro (mew-open-ssl-stream server sslport))
+	(when sslpro
+	  (setq sslname (process-name sslpro))
+	  (setq lport (mew-ssl-pnm-to-lport sslname))
+	  (when lport
+	    (setq process (mew-pop-open pnm "localhost" lport no-msg)))))
        (t
 	(setq process (mew-pop-open pnm server port no-msg))))
       (if (null process)
 	  (if (eq directive 'exec)
 	      (mew-summary-visible-buffer bnm))
-	(mew-summary-lock process "POPing")
+	(mew-summary-lock process "POPing" (or sshpro sslpro))
 	(mew-sinfo-set-scan-form (mew-summary-scan-form bnm))
 	(mew-sinfo-set-scan-id nil)
 	(mew-info-clean-up pnm)
@@ -609,6 +642,7 @@
 	(mew-pop-message pnm "Communicating with the POP server...")
 	(mew-pop-set-process pnm process)
 	(mew-pop-set-ssh-process pnm sshpro)
+	(mew-pop-set-ssl-process pnm sslpro)
 	(mew-pop-set-server pnm server)
 	(mew-pop-set-port pnm port)
 	(mew-pop-set-user pnm (mew-pop-user case))
@@ -667,7 +701,9 @@
        (mew-net-status2 (mew-pop-get-bnm pnm)
 			(mew-pop-get-rttl pnm)
 			(mew-pop-get-rcnt pnm)
-			(nth 2 (car (mew-pop-get-rtrs pnm)))))
+			(nth 2 (car (mew-pop-get-rtrs pnm)))
+			nil
+			(mew-pop-secure-p pnm)))
      (cond
       ((and (and (goto-char (point-min)) (looking-at "-ERR"))
 	    (and (goto-char (1- (point-max))) (looking-at "\n$")))
@@ -697,6 +733,7 @@
   (let* ((pnm (process-name process))
 	 (directive (mew-pop-get-directive pnm))
 	 (sshpro (mew-pop-get-ssh-process pnm))
+	 (sslpro (mew-pop-get-ssl-process pnm))
 	 (rttl (mew-pop-get-rttl pnm))
 	 (dttl (mew-pop-get-dttl pnm))
 	 (left (mew-pop-get-left pnm))
@@ -766,11 +803,14 @@
 	  (t
 	   (mew-pop-message pnm "%d messages deleted" dttl))))))
      ;;
+     (mew-net-status-clear (mew-pop-get-bnm pnm))
      (mew-info-clean-up pnm)
      (set-buffer-modified-p nil)
      (mew-summary-unlock)
      (if (and (processp sshpro) (not mew-ssh-keep-connection))
 	 (process-send-string sshpro "exit\n"))
+     (if (and (processp sslpro) (not mew-ssl-keep-connection))
+	 (delete-process sslpro))
      (unless (eq directive 'biff)
        (run-hooks 'mew-pop-sentinel-non-biff-hook))
      (run-hooks 'mew-pop-sentinel-hook)
@@ -807,7 +847,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2002 Mew developing team.
+;; Copyright (C) 1999-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
