@@ -16,19 +16,20 @@
   '(;; parameters to be saved
     "raw-header" "recipients" "orig-recipients"
     "bcc" "dcc" "fcc" "msgid" "logtime"
+    "case" ;; save for re-edit, not for sending
     ;; parameters used internally
-    "case" "server" "port" "ssh-server"
+    "server" "port" "ssh-server"
     "user" "auth-list"
     "helo-domain" 
-    "status" "ssh-process" "messages"
+    "status" "ssh-process" "ssl-process" "messages"
     ;; parameters used internally and should be initialized
     "string" "error" "auth-selected" "timer" "cont" "from" "sender"
     "done"))
 
 (mew-info-defun "mew-smtp-" mew-smtp-info-list)
 
-(defvar mew-smtp-info-list-save-length 8)
-(defvar mew-smtp-info-list-clean-length 18)
+(defvar mew-smtp-info-list-save-length 9)
+(defvar mew-smtp-info-list-clean-length 19)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -338,7 +339,7 @@
 	 (sshsrv (mew-smtp-ssh-server case))
 	 (sslp (mew-smtp-ssl case))
 	 (sslport (mew-smtp-ssl-port case))
-	 process sshname sshpro lport errmsg)
+	 process sshname sshpro sslname sslpro lport errmsg)
     (cond
      ((null (mew-smtp-get-recipients pnm))
       (message "No recipient!"))
@@ -350,19 +351,29 @@
       (cond
        (sshsrv
 	(setq sshpro (mew-open-ssh-stream server port sshsrv))
-	(mew-smtp-set-ssh-process pnm sshpro)
 	(when sshpro
 	  (setq sshname (process-name sshpro))
 	  (setq lport (mew-ssh-pnm-to-lport sshname))
 	  (when lport
 	    (setq process (mew-smtp-open pnm "localhost" lport)))))
        (sslp
-	(setq process (mew-open-ssl-stream pnm nil server sslport)))
+	(setq sslpro (mew-open-ssl-stream server sslport))
+	(when sslpro
+	  (setq sslname (process-name sslpro))
+	  (setq lport (mew-ssl-pnm-to-lport sslname))
+	  (when lport
+	    (setq process (mew-smtp-open pnm "localhost" lport)))))
        (t
 	(setq process (mew-smtp-open pnm server port))))
       (if (null process)
 	  (progn
-	    (setq errmsg "Cannot connect to the SMTP server")
+	    (cond
+	     ((and sshsrv (null sshpro))
+	      (setq errmsg "Cannot create to the SSH connection"))
+	     ((and sslp (null sslpro))
+	      (setq errmsg "Cannot create to the SSL connection"))
+	     (t
+	      (setq errmsg "Cannot connect to the SMTP server")))
 	    (mew-smtp-set-error pnm errmsg)
 	    (mew-smtp-queue case errmsg))
 	(mew-info-clean-up pnm mew-smtp-info-list-clean-length)
@@ -370,6 +381,8 @@
 	(mew-smtp-set-server pnm server)
 	(mew-smtp-set-port pnm port)
 	(mew-smtp-set-ssh-server pnm sshsrv)
+	(mew-smtp-set-ssh-process pnm sshpro)
+	(mew-smtp-set-ssl-process pnm sslpro)
 	(mew-smtp-set-helo-domain pnm (mew-smtp-helo-domain case))
 	(mew-smtp-set-user pnm (mew-smtp-user case))
 	(mew-smtp-set-auth-list pnm (mew-smtp-auth-list case))
@@ -440,11 +453,14 @@
 (defun mew-smtp-sentinel (process event)
   (let* ((pnm (process-name process))
 	 (done (mew-smtp-get-done pnm))
-	 (sshpro (mew-smtp-get-ssh-process pnm)))
+	 (sshpro (mew-smtp-get-ssh-process pnm))
+	 (sslpro (mew-smtp-get-ssl-process pnm)))
     (mew-smtp-debug "SMTP SENTINEL" event)
     (mew-info-clean-up pnm)
     (if (and (processp sshpro) (not mew-ssh-keep-connection))
 	(process-send-string sshpro "exit\n"))
+    (if (and (processp sslpro) (not mew-ssl-keep-connection))
+	(delete-process sslpro))
     (if done (message "Sending in background...done"))
     (run-hooks 'mew-smtp-sentinel-hook)))
 
@@ -464,6 +480,8 @@
     (setq file-info (mew-queue-enqueue work qfld))
     (setq file (nth 0 file-info) info (nth 1 file-info))
     (setq nname (mew-concat-folder qfld (file-name-nondirectory file)))
+    (if (mew-draft-p)
+	(mew-smtp-set-case pnm (mew-tinfo-get-case)))
     ;;
     (let* ((n mew-smtp-info-list-save-length)
 	   (data (make-vector n nil))
@@ -471,7 +489,7 @@
       (while (< i n)
 	(aset data i (aref (mew-info pnm) i))
 	(setq i (1+ i)))
-      (mew-smtp-set-recipients data (mew-smtp-get-recipients data))
+      (mew-smtp-set-recipients pnm (mew-smtp-get-orig-recipients pnm))
       (mew-lisp-save info data))
     ;;
     (mew-remove-buffer (current-buffer))
@@ -495,7 +513,7 @@
      (mew-smtp-set-orig-recipients pnm (mew-smtp-get-bcc pnm))
      (mew-smtp-set-bcc pnm nil)
      ;;
-     (mew-encode-id-date pnm case nil) ;; save-excursion
+     (mew-encode-id-date pnm (mew-smtp-message-id case)) ;; save-excursion
      (goto-char (point-max))
      (mew-draft-header-insert mew-to: "Bcc-Receiver:;")
      (mew-draft-header-insert mew-subj: mew-bcc-subject)
@@ -533,13 +551,14 @@
 	(msgid (mew-smtp-get-msgid pnm))
 	(recipients (mew-smtp-get-orig-recipients pnm))
 	(server (mew-smtp-get-server pnm))
-	(buf (generate-new-buffer mew-buffer-prefix)))
-    (save-excursion
-      (set-buffer buf)
-      (mew-erase-buffer)
+	(sshsrv (mew-smtp-get-ssh-server pnm))
+	(sslp (mew-smtp-get-ssl-process pnm)))
+    (with-temp-buffer
       (and logtime (insert logtime))
       (and msgid (insert " id=" msgid))
       (and server (insert " server=" server))
+      (and sshsrv (insert " sshsrv=" sshsrv))
+      (and sslp (insert " SSL"))
       (and recipients
 	   (setq recipients (mapconcat 'identity recipients ",")))
       (and recipients (insert " recipients=" recipients))
@@ -551,14 +570,13 @@
       (insert "\n")
       (write-region (point-min) (point-max)
 		    (expand-file-name mew-smtp-log-file mew-conf-path)
-		    'append 'no-msg))
-    (mew-remove-buffer buf)))
+		    'append 'no-msg))))
 
 (provide 'mew-smtp)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2002 Mew developing team.
+;; Copyright (C) 1999-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
