@@ -52,31 +52,34 @@
 ;;;
 
 (defun mew-summary-goto-folder (&optional goend)
-  "Go to the folder which you input.  If executed with
+  "Go to the folder which you specify.  If executed with
 '\\[universal-argument]', the cursor always goes to the bottom of
 Summary mode."
   (interactive "P")
   (let* ((proto (mew-proto-to-go (mew-summary-folder-name 'ext)))
-	 (inbox (mew-proto-inbox-folder proto mew-case-input))
-	 (fld (mew-input-folder inbox))
-	 (folder (mew-canonicalize-case-folder fld))
+	 (case (if (mew-folder-remotep proto)
+		   (mew-sinfo-get-case) ;; a remote folder
+		 mew-case-input)) ;; a local/virtual folder
+	 (inbox (mew-proto-inbox-folder	proto case))
+	 (folder (mew-input-folder case inbox))
 	 buf win frame goend)
-    (when mew-use-other-frame-for-summary
-      (if (setq buf (get-buffer folder))
-	  (if (setq win (get-buffer-window buf 0))
-	      (progn
-		(setq frame (window-frame win))
-		(raise-frame frame)
-		(select-frame frame)
-		;; Ensure, if possible, that frame gets input focus.
-		(if (eq window-system 'w32)
-		    (w32-focus-frame frame)
-		  (when focus-follows-mouse
-		    (set-mouse-position
-		     (selected-frame) (1- (frame-width)) 0))))
-	    (select-frame (make-frame)))
-	(select-frame (make-frame))))
-    (mew-summary-visit-folder folder goend)))
+    (when folder
+      (when mew-use-other-frame-for-summary
+	(if (setq buf (get-buffer folder))
+	    (if (setq win (get-buffer-window buf 0))
+		(progn
+		  (setq frame (window-frame win))
+		  (raise-frame frame)
+		  (select-frame frame)
+		  ;; Ensure, if possible, that frame gets input focus.
+		  (if (eq window-system 'w32)
+		      (w32-focus-frame frame)
+		    (when focus-follows-mouse
+		      (set-mouse-position
+		       (selected-frame) (1- (frame-width)) 0))))
+	      (select-frame (make-frame)))
+	  (select-frame (make-frame))))
+      (mew-summary-visit-folder folder goend))))
 
 (defun mew-summary-visit-folder (folder &optional goend no-ls)
   (let ((dir (mew-expand-folder folder))
@@ -119,9 +122,11 @@ Summary mode."
   "Jump to a message according to the number which you input.
 If 'mew-summary-jump-message-then-display' is non-nil,
 the message is then displayed."
-  (interactive)
+  (interactive "P")
+  (if (integerp msg) (setq msg (int-to-string msg))
+    (if (not (stringp msg)) (setq msg nil)))
   (let ((here (point)))
-    (unless msg (setq msg (read-string "Message No. : " "")))
+    (unless msg (setq msg (read-string "Message No.: " "")))
     (cond 
      ((string= msg "") ())
      ((eq msg t) ;; xxx
@@ -309,12 +314,74 @@ If called with '\\[universal-argument]', you can specify a printer name."
   (when (y-or-n-p "Print this message? ")
     (let ((printer-name (if arg
 			    (read-string "Printer name: ")
-			  printer-name)))
+			  printer-name))
+	  have-header str)
       (save-excursion
 	(set-buffer (mew-buffer-message))
 	(save-restriction
 	  (widen)
-	  (funcall mew-print-function))))))
+	  (setq have-header (mew-header-p))
+	  (setq str (mew-buffer-substring (point-min) (point-max)))))
+      (with-temp-buffer
+	(insert str)
+	(if have-header
+	    (mew-header-delete-other-lines mew-field-for-printing))
+	(funcall mew-print-function)))))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; X-Face:
+;;;
+
+(defun mew-summary-x-face ()
+  "Display xface."
+  (interactive)
+  (mew-summary-msg
+   (let ((file (mew-make-temp-name)) xface)
+     (save-excursion
+       (set-buffer (mew-buffer-message))
+       (setq xface (mew-header-get-value mew-x-face:)))
+     (when xface
+       (with-temp-buffer
+	 (insert xface)
+	 (mew-x-face-compface-to-xbm)
+	 (mew-frwlet
+	  mew-cs-dummy mew-cs-text-for-write
+	  (write-region (point-min) (point-max) file nil 'no-msg)))
+       (mew-mime-start-process
+	mew-prog-image/*-ext mew-prog-image/*-ext-arg file)))))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;
+;;; Calling a command
+;;;
+
+(defun mew-summary-cmd-msg ()
+  "Executing an external command specifying this message as an
+argument."
+  (interactive)
+  (mew-summary-msg-or-part
+   (let* ((fld (mew-summary-folder-name))
+	  (msg (mew-summary-message-number))
+	  (file (mew-expand-folder fld msg))
+	  (command (read-string "Command: ")))
+     (while (not (mew-which-exec command))
+       (setq command (read-string "Command: ")))
+     (message (format "Executing %s for %s..." command msg))
+     (call-process command nil nil nil file)
+     (message (format "Executing %s for %s...done" command msg)))))
+
+(defun mew-summary-cmd-msgs ()
+  "Executing an external command specifying messages
+marked with '@' as arguments."
+  (interactive)
+  (mew-summary-multi-msgs
+   (let ((command (read-string "Command: ")))
+     (while (not (mew-which-exec command))
+       (setq command (read-string "Command: ")))
+     (message (format "Executing %s ..." command))
+     (apply 'call-process command nil nil nil FILES)
+     (message (format "Executing %s ...done" command)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -395,7 +462,7 @@ If called with '\\[universal-argument]', options are asked."
 	(cond
 	 (fname
 	  (setq ct (or (mew-ctdb-ct (mew-ctdb-by-file fname))
-		       (mew-content-type mew-case-input))) ;; xxx
+		       (mew-content-type (mew-sinfo-get-case))))
 	  (setq pt "Type for %s (%s): ")
 	  (setq fl fname))
 	 (t
@@ -453,40 +520,6 @@ If called with '\\[universal-argument]', options are asked."
 		    (mew-mime-start-process program options file)
 		  (mew-mime-call-process program options file)))))))))))
   
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;
-;;; X-Face:
-;;;
-
-(defun mew-summary-x-face ()
-  "Display xface."
-  (interactive)
-  (mew-summary-msg
-   (let ((filters mew-x-face-filter) filter filter-arg file xface buf)
-     (save-excursion
-       (set-buffer (mew-buffer-message))
-       (when (setq xface (mew-header-get-value mew-x-face:))
-	 (setq buf (generate-new-buffer mew-buffer-prefix))
-	 (set-buffer buf)
-	 (mew-erase-buffer)
-	 (insert xface)
-	 (while filters
-	   (setq filter (car filters))
-	   (if (stringp filter)
-	       (setq filter-arg nil)
-	     (setq filter-arg (cdr filter))
-	     (setq filter (car filter)))
-	   ;; call-process-region is OK...
-	   (mew-plet
-	    (apply 'call-process-region
-		   (point-min) (point-max) filter 'delete t nil filter-arg))
-	   (setq filters (cdr filters)))
-	 (setq file (mew-make-temp-name))
-	 ;; NEVER use call-process-region for privary reasons
-	 (mew-flet
-	  (write-region (point-min) (point-max) file nil 'no-msg))
-	 (mew-mime-start-process mew-x-face-prog mew-x-face-args file))))))
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Flushing the queue
@@ -596,12 +629,10 @@ the other network processes are also hung up."
     (t
      (let ((dir (mew-summary-input-directory-name))
 	   (fn nil)
-	   (buf (generate-new-buffer mew-buffer-prefix))
 	   (tmp (mew-make-temp-name))
 	   (case-fold-search nil)
 	   (files FILES) start)
-       (save-excursion
-	 (set-buffer buf)
+       (with-temp-buffer
 	 (mew-frwlet
 	  mew-cs-text-for-read mew-cs-text-for-write
 	  (while files
@@ -632,8 +663,7 @@ the other network processes are also hung up."
 		      (y-or-n-p (format "Execute %s for %s? " mew-prog-tar fn)))
 	     (message "Executing %s for %s..." mew-prog-tar fn)
 	     (call-process mew-prog-tar nil nil nil "-xf" fn)
-	     (message "Executing %s for %s...done" mew-prog-tar fn))))
-       (mew-remove-buffer buf))))))
+	     (message "Executing %s for %s...done" mew-prog-tar fn)))))))))
 
 (defun mew-summary-prog-exec (prog opts suffix tarfile)
   (if (string-match (format "^\\(.*\\)\\.%s$" suffix) tarfile)
@@ -661,14 +691,11 @@ message."   (interactive)
 	   (folder (mew-input-burst-folder))
 	   (tfile (mew-make-temp-name))
 	   (targets FLD-MSG-LIST)
-	   (buf (generate-new-buffer mew-buffer-prefix))
 	   fld-msg num ct med dbl vec len idx ttl TTL fid FID i ent
 	   beg regex)
        (message "Joining...")
-       (save-excursion
-	 (set-buffer buf)
+       (with-temp-buffer
 	 (mew-set-buffer-multibyte t)
-	 (mew-erase-buffer)
 	 (insert "CD: " cfld "\n")
 	 (while targets
 	   (setq fld-msg (car targets))
@@ -769,10 +796,9 @@ message."   (interactive)
 	    (setq i (1+ i)))
 	  (write-region (point-min) (point-max)
 			(mew-folder-new-message folder)
-			nil 'no-msg))
-	 (mew-touch-folder folder)
-	 (message "Joining...done"))
-       (mew-remove-buffer buf)
+			nil 'no-msg)))
+       (mew-touch-folder folder)
+       (message "Joining...done")
        (if (y-or-n-p (format "Go to %s? " folder))
 	   (mew-summary-visit-folder folder 'goend)))))))
 
@@ -788,16 +814,17 @@ to clean up."
   (interactive "P")
   (let* ((folder mew-trash-folder)
 	 trashdir msgs)
-    (if arg (setq folder (mew-input-folder mew-trash-folder)))
-    (setq trashdir (mew-expand-folder folder))
-    (setq msgs (mew-dir-messages trashdir))
-    (if (null msgs)
-	(message "No messages to be removed in %s" folder)
-      (when (y-or-n-p (format "Remove all messages in %s? " folder))
-	(message "Removing all messages in %s..." folder)
-	(mew-summary-unlink-msgs folder msgs)
-	(mew-summary-folder-cache-clean folder)
-	(message "Removing all messages in %s...done" folder)))))
+    (if arg (setq folder (mew-input-folder nil mew-trash-folder)))
+    (when folder
+      (setq trashdir (mew-expand-folder folder))
+      (setq msgs (mew-dir-messages trashdir))
+      (if (null msgs)
+	  (message "No messages to be removed in %s" folder)
+	(when (y-or-n-p (format "Remove all messages in %s? " folder))
+	  (message "Removing all messages in %s..." folder)
+	  (mew-summary-unlink-msgs folder msgs)
+	  (mew-summary-folder-cache-clean folder)
+	  (message "Removing all messages in %s...done" folder))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -815,28 +842,28 @@ to clean up."
        (mew-summary-goto-message)
        (setq msg (mew-summary-message-number)))
      (setq file (mew-expand-folder fld msg))
-     (setq dstfld (mew-input-folder mew-inbox-folder)) ;; local folder only
-     (mew-local-folder-check dstfld)
-     (setq dstmsg (mew-folder-new-message dstfld 'numonly))
-     (setq dstfile (mew-expand-folder dstfld dstmsg))
-     (when (get-buffer dstfld)
-       (set-buffer dstfld)
-       (setq exclusivep (mew-summary-exclusive-p)))
-     (cond
-      ((not exclusivep)
-       (message "Try again later"))
-      ((string= file dstfile)
-       (message "You cannot copy this onto itself"))
-      (t
-       (mew-summary-local-copy-one file dstfile)
-       (mew-touch-folder dstfld)
-       (message "Copied to %s/%s" dstfld dstmsg))))))
+     (setq dstfld (mew-input-local-folder mew-inbox-folder))
+     (when (and dstfld (mew-local-folder-check dstfld 'ask))
+       (setq dstmsg (mew-folder-new-message dstfld 'numonly))
+       (setq dstfile (mew-expand-folder dstfld dstmsg))
+       (when (get-buffer dstfld)
+	 (set-buffer dstfld)
+	 (setq exclusivep (mew-summary-exclusive-p)))
+       (cond
+	((not exclusivep)
+	 (message "Try again later"))
+	((string= file dstfile)
+	 (message "You cannot copy this onto itself"))
+	(t
+	 (mew-summary-local-copy-one file dstfile)
+	 (mew-touch-folder dstfld)
+	 (message "Copied to %s/%s" dstfld dstmsg)))))))
 
 (defun mew-summary-mark-local-copy (&optional arg)
   "Copy cached message marked with '*' in a remote folder to a local
 folder."
   (interactive "P")
-  (mew-summary-msg-or-part
+  (mew-summary-not-in-draft
    (let ((mew-use-highlight-x-face nil)
 	 (fld (mew-summary-folder-name))
 	 (exclusivep t)
@@ -850,42 +877,38 @@ folder."
       (t
        (setq beg (point-min))
        (setq end (point-max))))
-     (setq dstfld (mew-input-folder mew-inbox-folder)) ;; local folder only
-     (mew-local-folder-check dstfld)
-     (setq dstmsg (mew-folder-new-message dstfld 'numonly))
-     (setq msgs (mew-summary-mark-collect mew-mark-review beg end))
-     (when (get-buffer dstfld)
-       (save-excursion
-	 (set-buffer dstfld)
-	 (setq exclusivep (mew-summary-exclusive-p))))
-     (cond
-      ((null msgs)
-       (message "No mark"))
-      ((not exclusivep)
-       (message "Try again later"))
-      (t
-       (message "Copying...")
-       (while msgs
-	 (setq file (mew-expand-folder fld (car msgs)))
-	 (setq dstfile (mew-expand-folder dstfld dstmsg))
-	 (mew-summary-local-copy-one file dstfile)
-	 (setq dstmsg (number-to-string (1+ (string-to-number dstmsg))))
-	 (setq msgs (cdr msgs)))
-       (mew-touch-folder dstfld)
-       (message "Copying...done"))))))
+     (setq dstfld (mew-input-local-folder mew-inbox-folder))
+     (when (and dstfld (mew-local-folder-check dstfld 'ask))
+       (setq dstmsg (mew-folder-new-message dstfld 'numonly))
+       (setq msgs (mew-summary-mark-collect mew-mark-review beg end))
+       (when (get-buffer dstfld)
+	 (save-excursion
+	   (set-buffer dstfld)
+	   (setq exclusivep (mew-summary-exclusive-p))))
+       (cond
+	((null msgs)
+	 (message "No mark"))
+	((not exclusivep)
+	 (message "Try again later"))
+	(t
+	 (message "Copying...")
+	 (while msgs
+	   (setq file (mew-expand-folder fld (car msgs)))
+	   (setq dstfile (mew-expand-folder dstfld dstmsg))
+	   (mew-summary-local-copy-one file dstfile)
+	   (setq dstmsg (number-to-string (1+ (string-to-number dstmsg))))
+	   (setq msgs (cdr msgs)))
+	 (mew-touch-folder dstfld)
+	 (message "Copying...done")))))))
 
 (defun mew-summary-local-copy-one (srcfile dstfile)
-  (let ((buf (generate-new-buffer mew-buffer-prefix)))
-    (save-excursion
-      (set-buffer buf)
-      (mew-erase-buffer)
-      (mew-frwlet
-       mew-cs-text-for-read mew-cs-text-for-write
-       (insert-file-contents srcfile)
-       (goto-char (point-min))
-       (mew-header-delete-lines (list mew-x-mew-uidl:))
-       (write-region (point-min) (point-max) dstfile nil 'no-msg)))
-    (mew-remove-buffer buf)))
+  (with-temp-buffer
+    (mew-frwlet
+     mew-cs-text-for-read mew-cs-text-for-write
+     (insert-file-contents srcfile)
+     (goto-char (point-min))
+     (mew-header-delete-lines (list mew-x-mew-uidl:))
+     (write-region (point-min) (point-max) dstfile nil 'no-msg))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -995,7 +1018,7 @@ If 'mew-warning-field-level' is 1, set it to 2."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2002 Mew developing team.
+;; Copyright (C) 1996-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
