@@ -415,7 +415,7 @@
       (setq ctdb (mew-ctdb-by-file file))
       (setq ct (mew-ctdb-ct ctdb))
       (unless ct
-	(setq ct (mew-content-type)) ;; xxx case?
+	(setq ct (mew-content-type (mew-tinfo-get-case)))
 	(setq ctdb (mew-ctdb-by-ct ct)))
       (setq ctl (list ct))))
     (or cte (setq cte (mew-ctdb-cte ctdb)))
@@ -885,9 +885,6 @@
 (defsubst mew-encode-syntax-have-one-part ()
   (= (length mew-encode-syntax) (1+ mew-syntax-magic)))
 
-(defsubst mew-encode-syntax-have-multiple-parts ()
-  (> (length mew-encode-syntax) (1+ mew-syntax-magic)))
-
 ;; point
 
 (defsubst mew-decode-syntax-begin ()
@@ -1011,7 +1008,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2002 Mew developing team.
+;; Copyright (C) 1996-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
