@@ -496,6 +496,7 @@ in draft buffer.")
     (,mew-subj:          text       text)
     (,mew-keywords:      comma-text text)
     (,mew-received:      unstruct   unstruct)
+    (,mew-message-id:    unstruct   unstruct)
     (,mew-references:    unstruct   unstruct)
     (,mew-in-reply-to:   unstruct   unstruct)
     (,mew-x-face:	 unstruct   unstruct))
@@ -934,11 +935,11 @@ following in .emacs.
 
 Currently, the following keys are supported: 
 \"name\", \"user\", \"mail-domain\", 
-\"smtp-msgid-domain\", \"smtp-msgid-user\", 
 \"cc\", \"fcc\", \"dcc\", \"reply-to\",
 \"organization\", \"header-alist\", 
 \"smtp-server\", \"smtp-port\", \"smtp-ssh-server\", 
 \"smtp-ssl\", \"smtp-ssl-port\", 
+\"smtp-msgid-user\", \"smtp-msgid-domain\", 
 \"smtp-helo-domain\", \"smtp-mail-from\", 
 \"smtp-user\", \"smtp-auth\", \"smtp-auth-list\", 
 \"pop-server\", \"pop-port\", \"pop-ssh-server\", 
@@ -951,12 +952,14 @@ Currently, the following keys are supported:
 \"nntp-server\", \"nntp-port\", \"nntp-ssh-server\", 
 \"nntp-ssl\", \"nntp-ssl-port\", 
 \"nntp-user\", \"nntp-size\", \"nntp-folder\",
+\"nntp-msgid-user\", \"nntp-msgid-domain\", 
 \"inbox-folder\", \"queue-folder\",
 \"mailbox-type\", \"mbox-command\", \"mbox-command-arg\", 
 \"signature-file\", \"content-type\" .
 
 from = name <user@mail-domain>
-message-id = *random*.user@smtp-msgid-domain
+message-id = *random*.smtp-msgid-user@smtp-msgid-domain
+message-id = *random*.nntp-msgid-user@nntp-msgid-domain
 
 An example is as follows:
 
@@ -985,7 +988,7 @@ An example is as follows:
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2000-2002 Mew developing team.
+;; Copyright (C) 2000-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
