@@ -2,7 +2,7 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Mar 23, 1994
-;; Revised: Dec  2, 2002
+;; Revised: Feb  5, 2003
 
 ;;; Commentary:
 
@@ -19,7 +19,7 @@
 ;;; Mew version
 ;;;
 
-(defconst mew-version-number "3.1"
+(defconst mew-version-number "3.1.53"
   "Version number for this version of Mew.")
 (defconst mew-version (format "Mew version %s" mew-version-number)
   "Version string for this version of Mew.")
@@ -146,10 +146,10 @@ CONTINUE, YANK-ACTION and SEND-ACTIONS are ignored."
 ;;;
 
 (defun mew-init ()
-  (let ((buf (generate-new-buffer mew-buffer-prefix)))
+  (with-temp-buffer
     (run-hooks 'mew-env-hook)
     (load mew-rc-file 'no-err 'no-msg)
-    (switch-to-buffer buf)
+    (switch-to-buffer (current-buffer))
     (mew-window-configure '(1 0)) ;; Using mew-mode-name-message
     (mew-hello)
     (message "Setting up Mew world...")
@@ -159,8 +159,7 @@ CONTINUE, YANK-ACTION and SEND-ACTIONS are ignored."
     (mew-passwd-setup)
     (mew-highlight-timer-setup)
     (setq mew-init-p t)
-    (message "Setting up Mew world...done")
-    (mew-remove-buffer buf)))
+    (message "Setting up Mew world...done")))
 
 (defun mew-set-environment (&optional no-dir)
   (let (error-message)
@@ -262,6 +261,7 @@ If executed with '3', information about IMAP folders is updated. "
     (mew-scan-setup)
     (mew-pgp-setup)
     (mew-ssh-setup)
+    (mew-ssl-setup)
     (mew-net-setup)
     (mew-thread-setup)
     (mew-theme-setup)
@@ -351,6 +351,24 @@ If executed with '3', information about IMAP folders is updated. "
 ;;;
 ;;; Window configuration
 ;;;
+(defun mew-delete-other-window ()
+  (unless (one-window-p)
+    (let ((owin (selected-window))
+	  wins ret)
+      (walk-windows
+       (lambda (win)
+	 (set-buffer (window-buffer win))
+	 (unless (or (eq owin win)
+		     (string-match "^mew-" (symbol-name major-mode)))
+	   (setq wins (cons win wins))))
+       nil)
+      (while wins
+	(unless (one-window-p)
+	  (setq ret t)
+	  (delete-window (car wins)))
+	(setq wins (cdr wins)))
+      (select-window owin)
+      ret)))
 
 (defun mew-window-configure (action)
   "Configure windows accroding to ACTION.
@@ -374,11 +392,15 @@ the lower window is not zero, switch to the buffer."
 	 (height nil) (winsum nil) (sum-height 0) (msg-height 0))
     (setq height (+ (if obufwin (window-height obufwin) 0)
 		    (if msgwin  (window-height msgwin)  0)))
-    (when (or mew-use-full-window
-	      (<= height (* 2 window-min-height)))
+    (cond
+     ((<= height (* 2 window-min-height))
       ;; Delete other windows and use full emacs window.
       (delete-other-windows)
       (setq height (window-height (selected-window))))
+     ((and mew-use-full-window (mew-delete-other-window))
+      ;; delete windows all but Mew's one.
+      (setq height (+ (if obufwin (window-height obufwin) 0)
+		      (if msgwin  (window-height msgwin)  0)))))
     ;;
     (if (get-buffer msgbuf)
 	(delete-windows-on msgbuf)
@@ -409,19 +431,35 @@ the lower window is not zero, switch to the buffer."
 ;;; Message buffer
 ;;;
 
+(defun mew-window-number ()
+  (let ((x (car (mew-window-edges (selected-window))))
+	(i 1))
+    (walk-windows
+     (lambda (win)
+       (when (save-excursion
+	       (set-buffer (window-buffer win))
+	       (mew-summary-or-virtual-p))
+	 (if (< (car (mew-window-edges win)) x)
+	     (setq i (1+ i)))))
+     'nominibuf)
+    i))
+
 (defun mew-buffer-message ()
   (let* ((me (selected-frame))
 	 (frames (frame-list))
 	 (len (length frames))
+	 (n (mew-window-number))
 	 (i 0))
     (catch 'loop
       (while frames
-      (if (equal me (car frames))
-	  (throw 'loop i))
-      (setq i (1+ i))
-      (setq frames (cdr frames))))
+	(if (equal me (car frames))
+	    (throw 'loop i))
+	(setq i (1+ i))
+	(setq frames (cdr frames))))
     (setq i (- len i 1))
-    (format "%s%d" mew-buffer-message i)))
+    (if (= n 1)
+	(format "%s%d" mew-buffer-message i)
+      (format "%s%d<%d>" mew-buffer-message i n))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -686,7 +724,7 @@ Mew remain, so you can resume with buffer operations."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1994-2002 Mew developing team.
+;; Copyright (C) 1994-2003 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
